@@ -1,8 +1,5 @@
 package Message::SmartMerge;
-{
-  $Message::SmartMerge::VERSION = '1.132270';
-}
-
+$Message::SmartMerge::VERSION = '1.161240';
 use 5.006;
 use strict;
 use warnings FATAL => 'all';
@@ -248,6 +245,8 @@ sub new {
     my %args = @_;
     bless ($self, $class);
 
+    $self->{keep_only} = $args{keep_only}
+        if $args{keep_only};
     $self->{merges} = $args{state}->{merges} || {};
     $self->{instances} = $args{state}->{instances} || {};
     $self->config($args{state}->{config})
@@ -357,6 +356,17 @@ sub _expire_merges {
     }
 }
 
+sub _get_only {
+    my $self = shift;
+    my $message = shift;
+    if(not $self->{config} or not $self->{config}->{keep_only}) {
+        return $message;
+    }
+    my $ret = {};
+    $ret->{$_} = $message->{$_} for @{$self->{config}->{keep_only}};
+    return $ret;
+}
+
 =head2 add_merge
 
     $merge->add_merge({
@@ -525,11 +535,11 @@ sub message {
         $instances->{$instance_name} = {
             cleared_merges => {},
             initial_ts => time,
-            message => $message,
+            message => $self->_get_only($message),
         };
     } else {
         $previous_message = $instances->{$instance_name}->{message};
-        $instances->{$instance_name}->{message} = $message;
+        $instances->{$instance_name}->{message} = $self->_get_only($message);
     }
     my $instance = $instances->{$instance_name};
     my $matching_merge_ids = {};
